from argparse import ArgumentParser
from argparse import Namespace
from kubernetes import client, config
import re

def get_args() -> Namespace:
    parser = ArgumentParser(
        prog="Cluster Search Thing",
        description="General utility for finding resources for game server bot"
    )
    games = {"reflex", "minecraft", "nginx"}
    parser.add_argument('-g', '--game', required=True, choices=games)
    return parser.parse_args()

def k8s_api(config_path: str) -> client.api.core_v1_api.CoreV1Api:
    config.load_kube_config("../config.yaml")
    print("Getting pod name of our game requested")
    return client.CoreV1Api()

if __name__ == '__main__':
    args = get_args()

    # Setting up k8s stuff
    api = k8s_api('../config.yaml')
    print(type(api))
    pods = api.list_pod_for_all_namespaces(label_selector=f'app={args.game}')

    # Now we collect specific data about the game server we requested
    port = pods.items[0].spec.containers[0].ports[0].container_port

    # Collecting the IPV4 of the node that contains the pod(container)
    # we actually care about. Since these pods only have 1 container
    node_name = pods.items[0].spec.node_name
    node_ips  = list(filter(lambda a: a.type == 'ExternalIP', api.list_node().items[0].status.addresses))
    ipv4 = list(filter(lambda item: not re.match('[\d\.]{3}\d', item.address), node_ips))[0].address
    ipv6 = list(filter(lambda item: re.match('[\d\.]{3}\d', item.address), node_ips))[0].address
    
    print(f'{args.game} --> {ipv4}:{port} ~~> {ipv6}:{port}')